@@ -30,6 +30,7 @@ extension_to_mime_type = {
   ".aif": "audio/x-aiff",
   ".aifc": "audio/x-aiff",
   ".aiff": "audio/x-aiff",
+  ".avif": "image/avif",
   ".air": "application/vnd.adobe.air-application-installer-package+zip",
   ".ami": "application/vnd.amiga.ami",
   ".apk": "application/vnd.android.package-archive",
@@ -149,6 +150,7 @@ extension_to_mime_type = {
   ".dmg": "application/octet-stream",
   ".dms": "application/octet-stream",
   ".dna": "application/vnd.dna",
+  ".dng": "image/x-adobe-dng",
   ".doc": "application/msword",
   ".docm": "application/vnd.ms-word.document.macroenabled.12",
   ".docx": "application/vnd.openxmlformats-officedocument.wordprocessingml.document",
@@ -256,6 +258,8 @@ extension_to_mime_type = {
   ".h264": "video/h264",
   ".hbci": "application/vnd.hbci",
   ".hdf": "application/x-hdf",
+  ".heic": "image/heif",
+  ".heif": "image/heif",
   ".hh": "text/x-c",
   ".hlp": "application/winhlp",
   ".hpgl": "application/vnd.hp-hpgl",
@@ -350,6 +354,7 @@ extension_to_mime_type = {
   ".m2v": "video/mpeg",
   ".m3a": "audio/mpeg",
   ".m3u": "audio/x-mpegurl",
+  ".m4a": "audio/m4a",
   ".m4u": "video/vnd.mpegurl",
   ".m4v": "video/x-m4v",
   ".ma": "application/mathematica",
@@ -367,6 +372,7 @@ extension_to_mime_type = {
   ".mdi": "image/vnd.ms-modi",
   ".me": "text/troff",
   ".mesh": "model/mesh",
+  ".mkv": "video/x-matroska",
   ".mfm": "application/vnd.mfmp",
   ".mgz": "application/vnd.proteus.magazine",
   ".mht": "message/rfc822",
@@ -743,6 +749,8 @@ extension_to_mime_type = {
   ".wad": "application/x-doom",
   ".wav": "audio/x-wav",
   ".wax": "audio/x-ms-wax",
+  ".webp": "image/webp",
+  ".webm": "video/webm",
   ".wbmp": "image/vnd.wap.wbmp",
   ".wbs": "application/vnd.criticaltools.wbs+xml",
   ".wbxml": "application/vnd.wap.wbxml",
